@@ -92,7 +92,6 @@ def yaml_dump(dict_to_dump):
     yaml.Representer = FlattenAliasRepresenter
     _add_yaml_1_1_boolean_resolvers(yaml.Resolver)
     yaml.Representer.add_representer(OrderedDict, _dict_representer)
-    yaml.Representer.add_representer(dict, _dict_representer)
 
     return dump_yaml_to_str(yaml, dict_to_dump)
 
@@ -113,7 +112,7 @@ def yaml_parse(yamlstr):
     except ValueError:
         yaml = ruamel.yaml.YAML(typ="safe", pure=True)
         yaml.Constructor.add_constructor(
-            ruamel.yaml.resolver.BaseResolver.DEFAULT_MAPPING_TAG,
+            str(ruamel.yaml.resolver.BaseResolver.DEFAULT_MAPPING_TAG),
             _dict_constructor)
         yaml.Constructor.add_multi_constructor(
             "!", intrinsics_multi_constructor)
